local function cmp_init()
	local cmp = require'cmp'
	local snippy = require'snippy'

	cmp.setup({
		snippet = {
			expand = function(args)
				snippy.expand_snippet(args.body)
			end,
		},
		window = {
			--completion = cmp.config.window.bordered(),
			--documentation = cmp.config.window.bordered(),
		},
		mapping = cmp.mapping.preset.insert({
			['<C-b>'] = cmp.mapping.scroll_docs(-4),
			['<C-f>'] = cmp.mapping.scroll_docs(4),
			['<C-e>'] = cmp.mapping(cmp.mapping.select_next_item(), {'i', 'c'}),
			['<C-y>'] = cmp.mapping(cmp.mapping.select_prev_item(), {'i', 'c'}),
			['<C-o>'] = cmp.mapping.confirm({
				behavior = cmp.ConfirmBehavior.Replace,
				select = true
			}),
			['<C-l>'] = cmp.mapping(function(fallback)
				if snippy.can_jump(1) then
					snippy.next()
				else
					fallback()
				end
			end, { 'i', 's' }),
			['<C-h>'] = cmp.mapping(function(fallback)
				if snippy.can_jump(-1) then
					snippy.previous()
				else
					fallback()
				end
			end, { 'i', 's' }),
		}),
		sources = cmp.config.sources({
			{name = 'nvim_lsp'},
			{name = 'snippy'},
		}, {
			{name = 'omni'},
		}, {
			{name = 'buffer'},
			{name = 'path'},
		})
	})
end

return {
	'hrsh7th/nvim-cmp',
	config = cmp_init,
	event = 'InsertEnter',
	dependencies = {
		'hrsh7th/cmp-nvim-lsp',
		'hrsh7th/cmp-buffer',
		'hrsh7th/cmp-path',
		'hrsh7th/cmp-omni',
		{
			'dcampos/nvim-snippy',
			dependencies = { 'dcampos/cmp-snippy', {'kovmir/vim-snippets', url='https://git.darkn.space/kovmir/vim-snippets.git'} }
		},
	}
}
